/* --COPYRIGHT--,BSD
 * Copyright (c) 2015, Texas Instruments Incorporated
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 *
 * *  Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 *
 * *  Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 *
 * *  Neither the name of Texas Instruments Incorporated nor the names of
 *    its contributors may be used to endorse or promote products derived
 *    from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
 * PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR
 * CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
 * EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
 * OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY,
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
 * OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE,
 * EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 * --/COPYRIGHT--*/

/*
 * variable_lib.h
 * This header file is associated with Auto-Torque feature implementation fpr a stepper motor.
 * It consists of parameters that may or may not be changed based on the type of stepper motor chosen and operating conditions,
 * The Reference document provides a detailed description of handling this header file.
 *  Created on: Aug 28, 2015
 *      Author: a0226371, Preethi Peddagorla
 *      Texas Instruments
 */

#ifndef AUTO_TORQUE_IMPLEMENTATION_VARIABLE_LIB_H_
#define AUTO_TORQUE_IMPLEMENTATION_VARIABLE_LIB_H_

// PI controller parameters
int kp = 5;
float ki = 3;

int Speed_min = 70;                                                 // Minimum Reference Speed below which motor halts
int Speed_max_NC = 100;                                             //Maximum Reference Speed up to which motor runs under no control
int Speed_max = 258;                                                //Maximum Reference Speed of motor
int torque_min = 50;                                                //Minumum torque given to motor at all speeds

//look up table for getting present speed from adc output
static const unsigned int speed_4m_bemf[128] = { 0, 0, 0, 0, 0, 0, 0, 0, 75, 75,
		75, 75, 75, 75, 108, 108, 108, 108, 108, 117, 117, 117, 125, 141, 141,
		141, 150, 150, 166, 166, 166, 183, 183, 183, 191, 191, 200, 208, 208,
		208, 208, 208, 208, 208, 258, 258, 258, 258, 258, 258, 258, 258, 258,
		258, 258, 258, 258, 258, 258, 258, 258, 258, 258, 258, 258, 258, 258,
		258, 258, 258, 258, 258, 258, 258, 258, 258, 258, 258, 258, 258, 258,
		258, 258, 258, 258, 258, 258, 258, 258, 258, 258, 258, 258, 258, 258,
		258, 258, 258, 258, 258, 258, 258, 258, 258, 258, 258, 258, 258, 258,
		258, 258, 258, 258, 258, 258, 258, 258, 258, 258, 258, 258, 258, 258,
		258, 258, 258, 258, 258
};

//Obtaining speed reference from adc ouput
static const unsigned short int Speed_functn[32] = { 0, 8, 17, 25, 33, 42, 50,
		58, 67, 75, 83, 92, 100, 108, 117, 125, 133, 141, 150, 158, 166, 175,
		183, 191, 200, 208, 216, 225, 233, 241, 250, 258

};

// Obtaining timer period value corresponding to speed reference
static const unsigned int timer_period_new[32] = { 0, 9012, 4506, 3004, 2253,
		1802, 1502, 1287, 1126, 1001, 901, 819, 751, 693, 644, 601, 563, 530,
		501, 474, 451, 429, 410, 392, 375, 360, 347, 334, 322, 311, 300, 291

};


#endif /* AUTO_TORQUE_IMPLEMENTATION_VARIABLE_LIB_H_ */

